==> DATA_H_V1.9.8.3.zip: DATA_H_V1.9.8.3/H_Ctrl/CtrlCardExec.sh <==
#!/bin/sh
#mv /usr/Hseries/tmp/Data_CtrlCard/logo_1920x1080.bmp /usr/nova/etc/logo/logo_1920x1080.bmp
#dd if=/usr/Hseries/tmp/Data_CtrlCard/f8-kernel.img of=/dev/mmcblk0p6
#rm /usr/Hseries/tmp/Data_CtrlCard/f8-kernel.img
#dd if=/usr/Hseries/tmp/Data_CtrlCard/f8-loader.img of=/dev/mmcblk0p1
#rm /usr/Hseries/tmp/Data_CtrlCard/f8-loader.img

dd if=/usr/Hseries/tmp/Data_CtrlCard/hseries-loader.img of=/dev/mmcblk0p1
dd if=/usr/Hseries/tmp/Data_CtrlCard/hseries-kernel.img of=/dev/mmcblk0p6

tar -jxf /usr/Hseries/tmp/Data_CtrlCard/node.tar.bz2        -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/H_9U.tar.bz2        -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/GUI.tar.bz2         -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/font.tar.bz2        -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/driver_nova.tar.bz2 -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/cert.tar.bz2        -C /etc/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/openssh.tar.bz2     -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/openssl.tar.bz2     -C /usr/Hseries/tmp/Data_CtrlCard/

if [ ! -d /usr/Hseries/bin/web/data/ ];then
    mkdir /usr/Hseries/bin/web/data/
fi

if [ ! -f /usr/Hseries/bin/web/data/h9u.db ];then
    echo "move h9u.db"
    if [ -f /usr/Hseries/bin/web/h9u.db ];then
        cp /usr/Hseries/bin/web/h9u.db /usr/Hseries/bin/web/data/
    else
        cp /usr/Hseries/bin/web/H_9U/H_9U/conf/h9u.db /usr/Hseries/bin/web/data/
    fi
fi

if [ ! -e /etc/init.d/automode ];then
	mv /usr/Hseries/tmp/Data_CtrlCard/automode	/etc/init.d/
    chmod +x /etc/init.d/automode
	ln -s /etc/init.d/automode /etc/rc5.d/S05automode
fi

if [ -f /usr/Hseries/tmp/Data_CtrlCard/site-packages.zip ]; then
    cd /usr/Hseries/tmp/Data_CtrlCard
    unzip site-packages.zip
    cp  site-packages/*  /usr/Hseries/lib/python3.6/lib/python3.6/site-packages/ -a
    rm -rf site-packages
    cd -
fi

rm /usr/Hseries/bin/Middleware/node -rf
#rm /usr/Hseries/bin/Middleware/data -rf  
rm /usr/Hseries/bin/Middleware/font -rf
rm /usr/Hseries/bin/web/H_9U -rf
#rm /usr/Hseries/bin/GUI -rf
rm /usr/Hseries/bin/GUI/H9U_GUI
rm /usr/Hseries/bin/GUI/H9U_GUI_OTHER
rm /usr/Hseries/bin/GUI/PlayerServer
rm /usr/Hseries/bin/GUI/Config.json
rm /usr/nova/lib/libhal.so.3.2.21
rm /etc/ImageMagick-6/policy.xml
rm /usr/Hseries/bin/Hseries-shutdown.sh
rm /usr/Hseries/bin/Hseries-run.sh
rm /etc/nginx/nginx.conf
rm /usr/Hseries/bin/powerprocess
mv /etc/nginx/modules-enabled /etc/nginx/modules-enabled_bk


killall nginx

mv /usr/Hseries/tmp/Data_CtrlCard/node                   /usr/Hseries/bin/Middleware/  
mv /usr/Hseries/tmp/Data_CtrlCard/font                   /usr/Hseries/bin/Middleware/  
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H2 		 /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H5 		 /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H9 		 /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H9_10X5  /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H15      /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H15_Pro  /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H20U         /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_Alita_2U    /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_Alita_5U   /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_Alita_9U    /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_Alita_15U   /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_Alita_20U   /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/hw_version                /usr/Hseries/bin/Middleware/
mv /usr/Hseries/tmp/Data_CtrlCard/GUI/H9U_GUI            /usr/Hseries/bin/GUI 
mv /usr/Hseries/tmp/Data_CtrlCard/GUI/H9U_GUI_OTHER      /usr/Hseries/bin/GUI 
mv /usr/Hseries/tmp/Data_CtrlCard/GUI/PlayerServer       /usr/Hseries/bin/GUI 
mv /usr/Hseries/tmp/Data_CtrlCard/GUI/Config.json        /usr/Hseries/bin/GUI 
mv /usr/Hseries/tmp/Data_CtrlCard/H_9U /usr/Hseries/bin/web/H_9U
mv /usr/Hseries/tmp/Data_CtrlCard/Hseries-daemon.sh /usr/Hseries/bin/
mv /usr/Hseries/tmp/Data_CtrlCard/start_video.sh /usr/Hseries/bin/
mkdir /usr/share/fonts/chinese
mv /usr/Hseries/tmp/Data_CtrlCard/NotoSansHans-Regular.otf /usr/share/fonts/chinese
mv /usr/Hseries/tmp/Data_CtrlCard/libhal.so.3.2.21         /usr/nova/lib/
mv /usr/Hseries/tmp/Data_CtrlCard/libIcnGamma.so           /usr/nova/lib/
mv /usr/Hseries/tmp/Data_CtrlCard/policy.xml		       /etc/ImageMagick-6/
mv /usr/Hseries/tmp/Data_CtrlCard/Hseries-shutdown.sh	   /usr/Hseries/bin/
mv /usr/Hseries/tmp/Data_CtrlCard/Hseries-run.sh     	   /usr/Hseries/bin/
mv /usr/Hseries/tmp/Data_CtrlCard/log.sh     	   			/usr/Hseries/bin/
mv /usr/Hseries/tmp/Data_CtrlCard/setmode.sh     	   		/usr/Hseries/bin/
mv /usr/Hseries/tmp/Data_CtrlCard/nginx.conf        	   /etc/nginx/
mv /usr/Hseries/tmp/Data_CtrlCard/nginx                    /usr/sbin/
cp /usr/Hseries/tmp/Data_CtrlCard/init-task.sh  		   /etc/init.d/
mv /usr/Hseries/tmp/Data_CtrlCard/powerprocess      	   /usr/Hseries/bin/
cp /usr/Hseries/tmp/Data_CtrlCard/insmod-drvs.sh  		   /etc/init.d/
cp /usr/Hseries/tmp/Data_CtrlCard/mount-usb.sh  		   /etc/udev/
cp /usr/Hseries/tmp/Data_CtrlCard/umount-usb.sh  		   /etc/udev/
cp /usr/Hseries/tmp/Data_CtrlCard/11-add-usb.rules		   /etc/udev/rules.d/
cp /usr/Hseries/tmp/Data_CtrlCard/11-remove-usb.rules	   /etc/udev/rules.d/

cp -r /usr/Hseries/tmp/Data_CtrlCard/driver_nova           /usr/nova/
cp /usr/Hseries/tmp/Data_CtrlCard/ntpdate	   			   /etc/network/if-up.d/
cp /usr/Hseries/tmp/Data_CtrlCard/restore.py	   		   /usr/Hseries/bin/Middleware/ 
cp -r /usr/Hseries/tmp/Data_CtrlCard/serdes                /usr/Hseries/bin/Middleware/ 
cp -r /usr/Hseries/tmp/Data_CtrlCard/cp_level                /usr/Hseries/bin/Middleware/ 
cp /usr/Hseries/tmp/Data_CtrlCard/libpcre.so.1	 		   /usr/lib/arm-linux-gnueabihf/
cp /usr/Hseries/tmp/Data_CtrlCard/zlog.conf                /usr/Hseries/bin/Middleware/conf/

cp /usr/Hseries/tmp/Data_CtrlCard/journald.conf            /etc/systemd/

cp -rf /usr/Hseries/tmp/Data_CtrlCard/openssh/sbin 	       		/usr/
cp -rf /usr/Hseries/tmp/Data_CtrlCard/openssh/bin 	       		/usr/
cp /usr/Hseries/tmp/Data_CtrlCard/openssl/libcrypto.so.1.1  	/usr/lib/arm-linux-gnueabihf/
cp /usr/Hseries/tmp/Data_CtrlCard/openssl/libssl.so.1.1     	/usr/lib/arm-linux-gnueabihf/
cp /usr/Hseries/tmp/Data_CtrlCard/openssl/openssl           	/usr/bin/

chmod +x  /usr/sbin/*
chmod +x  /usr/bin/*

chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H2
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H5
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H9
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H9_10X5
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H15
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H15_Pro
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H20U
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_Alita_2U
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_Alita_5U
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_Alita_9U
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_Alita_15U
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_Alita_20U
chmod +x  /usr/Hseries/bin/GUI/H9U_GUI
chmod +x  /usr/Hseries/bin/GUI/H9U_GUI_OTHER
chmod +x  /usr/Hseries/bin/GUI/PlayerServer
chmod 777 /usr/nova/lib/libhal.so.3.2.21
chmod +x  /etc/init.d/init-task.sh  
chmod +x  /usr/Hseries/bin/powerprocess 
chmod +x  /etc/init.d/insmod-drvs.sh 
chmod +x  /etc/udev/mount-usb.sh
chmod +x  /etc/udev/umount-usb.sh
chmod +x  /etc/network/if-up.d/ntpdate
chmod 777 /etc/init.d/nginx
chmod 777 /usr/sbin/nginx

if [ -d /usr/Hseries/tmp/Data_CtrlCard/helpfile ];then
echo "change helpfile"
rm -rf /usr/Hseries/bin/web/helpfile 
cp -r /usr/Hseries/tmp/Data_CtrlCard/helpfile /usr/Hseries/bin/web/
fi

if [ ! -d  "/var/empty" ];then
	mkdir /var/empty
fi

/usr/bin/fc-cache
sync
rm /usr/Hseries/tmp/Data_CtrlCard/CtrlCardExec.sh

(echo "Pass123Word!";sleep 1;echo "Pass123Word!")|passwd >/dev/null

sync

sleep 2 && cd /usr/Hseries/bin && sh Hseries-shutdown.sh &

==> DATA_H_V1.9.9.2.zip: DATA_H_V1.9.9.2/H_Ctrl/CtrlCardExec.sh <==
#!/bin/sh
#mv /usr/Hseries/tmp/Data_CtrlCard/logo_1920x1080.bmp /usr/nova/etc/logo/logo_1920x1080.bmp
#dd if=/usr/Hseries/tmp/Data_CtrlCard/f8-kernel.img of=/dev/mmcblk0p6
#rm /usr/Hseries/tmp/Data_CtrlCard/f8-kernel.img
#dd if=/usr/Hseries/tmp/Data_CtrlCard/f8-loader.img of=/dev/mmcblk0p1
#rm /usr/Hseries/tmp/Data_CtrlCard/f8-loader.img

dd if=/usr/Hseries/tmp/Data_CtrlCard/hseries-loader.img of=/dev/mmcblk0p1
dd if=/usr/Hseries/tmp/Data_CtrlCard/hseries-kernel.img of=/dev/mmcblk0p6

tar -jxf /usr/Hseries/tmp/Data_CtrlCard/node.tar.bz2        -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/H_9U.tar.bz2        -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/GUI.tar.bz2         -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/font.tar.bz2        -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/driver_nova.tar.bz2 -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/cert.tar.bz2        -C /etc/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/openssh.tar.bz2     -C /usr/Hseries/tmp/Data_CtrlCard/
tar -jxf /usr/Hseries/tmp/Data_CtrlCard/openssl.tar.bz2     -C /usr/Hseries/tmp/Data_CtrlCard/

if [ ! -d /usr/Hseries/bin/web/data/ ];then
    mkdir /usr/Hseries/bin/web/data/
fi

if [ ! -f /usr/Hseries/bin/web/data/h9u.db ];then
    echo "move h9u.db"
    if [ -f /usr/Hseries/bin/web/h9u.db ];then
        cp /usr/Hseries/bin/web/h9u.db /usr/Hseries/bin/web/data/
    else
        cp /usr/Hseries/bin/web/H_9U/H_9U/conf/h9u.db /usr/Hseries/bin/web/data/
    fi
fi

if [ ! -e /etc/init.d/automode ];then
	mv /usr/Hseries/tmp/Data_CtrlCard/automode	/etc/init.d/
    chmod +x /etc/init.d/automode
	ln -s /etc/init.d/automode /etc/rc5.d/S05automode
fi

if [ -f /usr/Hseries/tmp/Data_CtrlCard/site-packages.zip ]; then
    cd /usr/Hseries/tmp/Data_CtrlCard
    unzip site-packages.zip
    cp  site-packages/*  /usr/Hseries/lib/python3.6/lib/python3.6/site-packages/ -a
    rm -rf site-packages
    cd -
fi

rm /usr/Hseries/bin/Middleware/node -rf
#rm /usr/Hseries/bin/Middleware/data -rf  
rm /usr/Hseries/bin/Middleware/font -rf
rm /usr/Hseries/bin/web/H_9U -rf
#rm /usr/Hseries/bin/GUI -rf
rm /usr/Hseries/bin/GUI/H9U_GUI
rm /usr/Hseries/bin/GUI/PlayerServer
rm /usr/Hseries/bin/GUI/Config.json
rm /usr/nova/lib/libhal.so.3.2.21
rm /etc/ImageMagick-6/policy.xml
rm /usr/Hseries/bin/Hseries-shutdown.sh
rm /usr/Hseries/bin/Hseries-run.sh
rm /usr/Hseries/bin/Hseries_env.sh
rm /etc/nginx/nginx.conf
rm /usr/Hseries/bin/powerprocess
mv /etc/nginx/modules-enabled /etc/nginx/modules-enabled_bk


killall nginx

mv /usr/Hseries/tmp/Data_CtrlCard/node                   /usr/Hseries/bin/Middleware/  
mv /usr/Hseries/tmp/Data_CtrlCard/font                   /usr/Hseries/bin/Middleware/  
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H2 		 /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H5 		 /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H9 		 /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H9_10X5  /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H15      /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H15_Pro  /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_H20U         /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_Alita_2U    /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_Alita_5U   /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_Alita_9U    /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_Alita_15U   /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/MasterProcess_Alita_20U   /usr/Hseries/bin/Middleware/ 
mv /usr/Hseries/tmp/Data_CtrlCard/hw_version                /usr/Hseries/bin/Middleware/
mv /usr/Hseries/tmp/Data_CtrlCard/GUI/H9U_GUI            /usr/Hseries/bin/GUI  
mv /usr/Hseries/tmp/Data_CtrlCard/GUI/PlayerServer       /usr/Hseries/bin/GUI 
mv /usr/Hseries/tmp/Data_CtrlCard/GUI/Config.json        /usr/Hseries/bin/GUI 
mv /usr/Hseries/tmp/Data_CtrlCard/H_9U /usr/Hseries/bin/web/H_9U
mv /usr/Hseries/tmp/Data_CtrlCard/Hseries-daemon.sh /usr/Hseries/bin/
mv /usr/Hseries/tmp/Data_CtrlCard/start_video.sh /usr/Hseries/bin/
mkdir /usr/share/fonts/chinese
mv /usr/Hseries/tmp/Data_CtrlCard/NotoSansHans-Regular.otf /usr/share/fonts/chinese
mv /usr/Hseries/tmp/Data_CtrlCard/libhal.so.3.2.21         /usr/nova/lib/
mv /usr/Hseries/tmp/Data_CtrlCard/libIcnGamma.so           /usr/nova/lib/
mv /usr/Hseries/tmp/Data_CtrlCard/libev.so                 /usr/nova/lib/
mv /usr/Hseries/tmp/Data_CtrlCard/libev.so.4               /usr/nova/lib/
mv /usr/Hseries/tmp/Data_CtrlCard/libev.so.4.0.0           /usr/nova/lib/
mv /usr/Hseries/tmp/Data_CtrlCard/policy.xml		       /etc/ImageMagick-6/
mv /usr/Hseries/tmp/Data_CtrlCard/Hseries-shutdown.sh	   /usr/Hseries/bin/
mv /usr/Hseries/tmp/Data_CtrlCard/Hseries-run.sh     	   /usr/Hseries/bin/
mv /usr/Hseries/tmp/Data_CtrlCard/Hseries_env.sh     	   /usr/Hseries/bin/
mv /usr/Hseries/tmp/Data_CtrlCard/log.sh     	   			/usr/Hseries/bin/
mv /usr/Hseries/tmp/Data_CtrlCard/setmode.sh     	   		/usr/Hseries/bin/
mv /usr/Hseries/tmp/Data_CtrlCard/nginx.conf        	   /etc/nginx/
mv /usr/Hseries/tmp/Data_CtrlCard/nginx                    /usr/sbin/
cp /usr/Hseries/tmp/Data_CtrlCard/init-task.sh  		   /etc/init.d/
mv /usr/Hseries/tmp/Data_CtrlCard/powerprocess      	   /usr/Hseries/bin/
cp /usr/Hseries/tmp/Data_CtrlCard/insmod-drvs.sh  		   /etc/init.d/
cp /usr/Hseries/tmp/Data_CtrlCard/mount-usb.sh  		   /etc/udev/
cp /usr/Hseries/tmp/Data_CtrlCard/umount-usb.sh  		   /etc/udev/
cp /usr/Hseries/tmp/Data_CtrlCard/11-add-usb.rules		   /etc/udev/rules.d/
cp /usr/Hseries/tmp/Data_CtrlCard/11-remove-usb.rules	   /etc/udev/rules.d/
mv /usr/Hseries/tmp/Data_CtrlCard/resolvconf.conf          /lib/systemd/system/systemd-resolved.service.d/

cp -r /usr/Hseries/tmp/Data_CtrlCard/driver_nova           /usr/nova/
cp /usr/Hseries/tmp/Data_CtrlCard/ntpdate	   			   /etc/network/if-up.d/
cp /usr/Hseries/tmp/Data_CtrlCard/restore.py	   		   /usr/Hseries/bin/Middleware/ 
cp -r /usr/Hseries/tmp/Data_CtrlCard/serdes                /usr/Hseries/bin/Middleware/ 
cp -r /usr/Hseries/tmp/Data_CtrlCard/cp_level                /usr/Hseries/bin/Middleware/ 
cp /usr/Hseries/tmp/Data_CtrlCard/libpcre.so.1	 		   /usr/lib/arm-linux-gnueabihf/
cp /usr/Hseries/tmp/Data_CtrlCard/zlog.conf                /usr/Hseries/bin/Middleware/conf/

cp /usr/Hseries/tmp/Data_CtrlCard/journald.conf            /etc/systemd/

cp -rf /usr/Hseries/tmp/Data_CtrlCard/openssh/sbin 	       		/usr/
cp -rf /usr/Hseries/tmp/Data_CtrlCard/openssh/bin 	       		/usr/
cp /usr/Hseries/tmp/Data_CtrlCard/openssl/libcrypto.so.1.1  	/usr/lib/arm-linux-gnueabihf/
cp /usr/Hseries/tmp/Data_CtrlCard/openssl/libssl.so.1.1     	/usr/lib/arm-linux-gnueabihf/
cp /usr/Hseries/tmp/Data_CtrlCard/openssl/openssl           	/usr/bin/

chmod +x  /usr/sbin/*
chmod +x  /usr/bin/*

chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H2
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H5
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H9
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H9_10X5
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H15
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H15_Pro
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_H20U
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_Alita_2U
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_Alita_5U
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_Alita_9U
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_Alita_15U
chmod +x  /usr/Hseries/bin/Middleware/MasterProcess_Alita_20U
chmod +x  /usr/Hseries/bin/GUI/H9U_GUI
chmod +x  /usr/Hseries/bin/GUI/PlayerServer
chmod 777 /usr/nova/lib/libhal.so.3.2.21
chmod +x  /etc/init.d/init-task.sh  
chmod +x  /usr/Hseries/bin/powerprocess 
chmod +x  /etc/init.d/insmod-drvs.sh 
chmod +x  /etc/udev/mount-usb.sh
chmod +x  /etc/udev/umount-usb.sh
chmod +x  /etc/network/if-up.d/ntpdate
chmod 777 /etc/init.d/nginx
chmod 777 /usr/sbin/nginx

if [ -d /usr/Hseries/tmp/Data_CtrlCard/helpfile ];then
echo "change helpfile"
rm -rf /usr/Hseries/bin/web/helpfile 
cp -r /usr/Hseries/tmp/Data_CtrlCard/helpfile /usr/Hseries/bin/web/
fi

if [ ! -d  "/var/empty" ];then
	mkdir /var/empty
fi

/usr/bin/fc-cache
sync
rm /usr/Hseries/tmp/Data_CtrlCard/CtrlCardExec.sh

(echo "Pass123Word!";sleep 1;echo "Pass123Word!")|passwd >/dev/null

sync

sleep 2 && cd /usr/Hseries/bin && sh Hseries-shutdown.sh &
